/* $Id: menu.js 4889 2009-04-06 12:52:39Z nicklas $
	------------------------------------------------------------------
	Copyright (C) 2005 Nicklas Nordborg
	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg, Gregory Vincic
	Copyright (C) 2007 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	JavaScript functions for the Menu taglib.

	@author Nicklas
	@version 2.0
*/

var Menu = new MenuClass();
document.onclick = function(event)
{
	Menu.hideAll();
}

function MenuClass()
{
	this.allVisible = new Array();
	this.numVisible = 0;
	this.zIndex = 999;

	this.showTopMenu = function(menu, x, y, keepForms)
	{
		this.hideAll();
		menu.style.left = (x)+'px';
		menu.style.top = (y)+'px';
		menu.style.display = 'block';
		menu.style.zIndex = this.zIndex++;
		menu.canHide = true;
		this.registerVisible(menu, keepForms);
	}
	
	this.toggleTopMenu = function(menu, x, y, keepForms)
	{
		if (menu.style.display == 'none')
		{
			this.showTopMenu(menu, x, y, keepForms);
		}
		else
		{
			this.hideSubMenus(menu);
		}
	}
	
	this.showSubMenu = function(menu, menuItem, subMenu, below)
	{
		this.hideSubMenus(menu);
		var offsetTop = 0;
		var offsetLeft = 0;
		var offsetTrail = menuItem;
		while (offsetTrail)
		{
			offsetTop += offsetTrail.offsetTop;
			offsetLeft += offsetTrail.offsetLeft;
			offsetTrail = offsetTrail.offsetParent;
		}
		if (below)
		{
			offsetTop += menuItem.offsetHeight;
		}
		else
		{
			offsetLeft += menuItem.offsetWidth;
		}
		subMenu.style.left = (offsetLeft)+'px';
		subMenu.style.top = (offsetTop)+'px';
		subMenu.style.display = 'block';
		subMenu.style.zIndex = this.zIndex++;
		Main.addClass(menuItem, 'active');
		menu.activeSubMenu = subMenu;
		this.registerVisible(menu);
	}

	this.hideSubMenus = function(menu)
	{
		var activeSubMenu = menu.activeSubMenu;
		if (activeSubMenu)
		{
			this.hideSubMenus(activeSubMenu);
			activeSubMenu.style.display = 'none';
			menu.activeSubMenu = null;
			this.unregisterVisible(menu);
		}
		if (menu.canHide) 
		{
			menu.style.display = 'none';
			this.unregisterVisible(menu);
		}
	}

	this.toggleSubMenu = function(menu, menuItem, subMenu, below)
	{
		if (menu.activeSubMenu == subMenu)
		{
			this.hideSubMenus(menu);
		}
		else
		{
			this.showSubMenu(menu, menuItem, subMenu, below);
		}
	}

	this.highlightMenuItem = function(menu, menuItem)
	{
		Main.addClass(menuItem, 'active');
		if (menu.activeSubMenu)
		{
			this.hideSubMenus(menu);
		}
	}

	this.downlightMenuItem = function(menu, menuItem)
	{
		Main.removeClass(menuItem, 'active');
	}
	
	this.highlightSubMenuItem = function(menu, menuItem, subMenu, below)
	{
		Main.addClass(menuItem, 'active');
		if (menu.activeSubMenu && (menu.activeSubMenu != subMenu))
		{
			this.hideSubMenus(menu);
			this.showSubMenu(menu, menuItem, subMenu, below);
		}
	}

	this.downlightSubMenuItem = function(menu, menuItem)
	{
		Main.removeClass(menuItem, 'active');
	}
	
	
	this.registerVisible = function(menu, keepForms)
	{
		this.numVisible++;
		if (keepForms == undefined)
		{
			keepForms = !Browser.hideFormElementsForMenu;
		}
		if (this.numVisible == 1 && !keepForms) this.hideForms();
		this.allVisible[this.allVisible.length] = menu;
	}
	
	this.unregisterVisible = function(menu)
	{
		this.numVisible--;
		if (this.numVisible == 0) this.showForms();
		for (var i = this.allVisible.length-1; i >= 0; i--)
		{
			if (this.allVisible[i] == menu) 
			{
				this.allVisible.splice(i, 1);
				return;
			}
		}
	}
	
	this.hideAll = function()
	{
		while (this.allVisible.length > 0)
		{
			this.hideSubMenus(this.allVisible[0]);
		}
		this.allVisible = new Array();
		this.showForms();
	}
	
	this.hideForms = function(win)
	{
		if (!win) win = window;
		var doc = win.document;
		for (var i = 0; i < doc.forms.length; i++)
		{
			var frm = doc.forms[i];
			for (var j = 0; j < frm.elements.length; j++)
			{
				frm.elements[j].style.visibility = 'hidden';
			}
		}
		if (win.frames && win.frames.length > 0)
		{
			for (var i = 0; i < win.frames.length; i++)
			{
				this.hideForms(win.frames[i]);
			}
		}
	}

	this.showForms = function(win)
	{
		if (!win) win = window;
		var doc = win.document;
		for (i = 0; i < doc.forms.length; i++)
		{
			var frm = doc.forms[i];
			for (var j = 0; j < frm.elements.length; j++)
			{
				frm.elements[j].style.visibility = 'inherit';
			}
		}
		if (win.frames && win.frames.length > 0)
		{
			for (var i = 0; i < win.frames.length; i++)
			{
				this.showForms(win.frames[i]);
			}
		}
	}
	
	this.openUrl = function(url, target)
	{
		var targetWindow = (target == null ? window : window.top.frames[target]);
		if (targetWindow != null)
		{
			targetWindow.location = url;
		}
		else
		{
			window.open(url, target);
		}
	}
}
